# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types.employers import (
    ServiceBundleListResponse,
    ServiceBundleCreateResponse,
    ServiceBundleUpdateResponse,
    ServiceBundleRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestServiceBundles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
            _id="_id",
            limit=0,
            occurrence="occurrence",
            recurring=True,
            roles=["string"],
            start_date="startDate",
        )
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: BlueHive) -> None:
        response = client.employers.service_bundles.with_raw_response.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = response.parse()
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: BlueHive) -> None:
        with client.employers.service_bundles.with_streaming_response.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = response.parse()
            assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_create(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.service_bundles.with_raw_response.create(
                employer_id="",
                bundle_name="x",
                service_ids=["string"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.retrieve(
            id="id",
            employer_id="employerId",
        )
        assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: BlueHive) -> None:
        response = client.employers.service_bundles.with_raw_response.retrieve(
            id="id",
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = response.parse()
        assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: BlueHive) -> None:
        with client.employers.service_bundles.with_streaming_response.retrieve(
            id="id",
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = response.parse()
            assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.service_bundles.with_raw_response.retrieve(
                id="id",
                employer_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.employers.service_bundles.with_raw_response.retrieve(
                id="",
                employer_id="employerId",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
            _id="_id",
            limit=0,
            occurrence="occurrence",
            recurring=True,
            roles=["string"],
            start_date="startDate",
        )
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: BlueHive) -> None:
        response = client.employers.service_bundles.with_raw_response.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = response.parse()
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: BlueHive) -> None:
        with client.employers.service_bundles.with_streaming_response.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = response.parse()
            assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.service_bundles.with_raw_response.update(
                id="id",
                employer_id="",
                bundle_name="x",
                service_ids=["string"],
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.employers.service_bundles.with_raw_response.update(
                id="",
                employer_id="employerId",
                bundle_name="x",
                service_ids=["string"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.list(
            "employerId",
        )
        assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: BlueHive) -> None:
        response = client.employers.service_bundles.with_raw_response.list(
            "employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = response.parse()
        assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: BlueHive) -> None:
        with client.employers.service_bundles.with_streaming_response.list(
            "employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = response.parse()
            assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_list(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.service_bundles.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: BlueHive) -> None:
        service_bundle = client.employers.service_bundles.delete(
            id="id",
            employer_id="employerId",
        )
        assert service_bundle is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: BlueHive) -> None:
        response = client.employers.service_bundles.with_raw_response.delete(
            id="id",
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = response.parse()
        assert service_bundle is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: BlueHive) -> None:
        with client.employers.service_bundles.with_streaming_response.delete(
            id="id",
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = response.parse()
            assert service_bundle is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.service_bundles.with_raw_response.delete(
                id="id",
                employer_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.employers.service_bundles.with_raw_response.delete(
                id="",
                employer_id="employerId",
            )


class TestAsyncServiceBundles:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
            _id="_id",
            limit=0,
            occurrence="occurrence",
            recurring=True,
            roles=["string"],
            start_date="startDate",
        )
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.service_bundles.with_raw_response.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = await response.parse()
        assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.service_bundles.with_streaming_response.create(
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = await response.parse()
            assert_matches_type(ServiceBundleCreateResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.create(
                employer_id="",
                bundle_name="x",
                service_ids=["string"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.retrieve(
            id="id",
            employer_id="employerId",
        )
        assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.service_bundles.with_raw_response.retrieve(
            id="id",
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = await response.parse()
        assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.service_bundles.with_streaming_response.retrieve(
            id="id",
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = await response.parse()
            assert_matches_type(ServiceBundleRetrieveResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.retrieve(
                id="id",
                employer_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.retrieve(
                id="",
                employer_id="employerId",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
            _id="_id",
            limit=0,
            occurrence="occurrence",
            recurring=True,
            roles=["string"],
            start_date="startDate",
        )
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.service_bundles.with_raw_response.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = await response.parse()
        assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.service_bundles.with_streaming_response.update(
            id="id",
            employer_id="employerId",
            bundle_name="x",
            service_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = await response.parse()
            assert_matches_type(ServiceBundleUpdateResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.update(
                id="id",
                employer_id="",
                bundle_name="x",
                service_ids=["string"],
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.update(
                id="",
                employer_id="employerId",
                bundle_name="x",
                service_ids=["string"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.list(
            "employerId",
        )
        assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.service_bundles.with_raw_response.list(
            "employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = await response.parse()
        assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.service_bundles.with_streaming_response.list(
            "employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = await response.parse()
            assert_matches_type(ServiceBundleListResponse, service_bundle, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncBlueHive) -> None:
        service_bundle = await async_client.employers.service_bundles.delete(
            id="id",
            employer_id="employerId",
        )
        assert service_bundle is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.service_bundles.with_raw_response.delete(
            id="id",
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        service_bundle = await response.parse()
        assert service_bundle is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.service_bundles.with_streaming_response.delete(
            id="id",
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            service_bundle = await response.parse()
            assert service_bundle is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.delete(
                id="id",
                employer_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.employers.service_bundles.with_raw_response.delete(
                id="",
                employer_id="employerId",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["FaxSendResponse"]


class FaxSendResponse(BaseModel):
    id: str
    """Unique fax identifier"""

    created_at: str = FieldInfo(alias="createdAt")
    """ISO timestamp when fax was created"""

    from_: str = FieldInfo(alias="from")
    """Sender fax number"""

    provider: str
    """Provider used to send the fax"""

    status: Literal["queued", "dialing", "sending", "delivered", "failed", "cancelled", "retrying"]
    """Current fax status"""

    to: str
    """Recipient fax number"""

    estimated_delivery: Optional[str] = FieldInfo(alias="estimatedDelivery", default=None)
    """Estimated delivery time (ISO timestamp)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ProviderLookupParams"]


class ProviderLookupParams(TypedDict, total=False):
    firstname: str
    """Provider first name"""

    lastname: str
    """Provider last name"""

    npi: str
    """Provider NPI number"""

    zipcode: str
    """ZIP code to filter results by proximity"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["IntegrationCheckActiveResponse"]


class IntegrationCheckActiveResponse(BaseModel):
    active: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel

__all__ = ["ProviderLookupResponse", "Provider"]


class Provider(BaseModel):
    address_1: str
    """Primary address line"""

    address_2: str
    """Secondary address line (suite, unit, etc.)"""

    city: str
    """City"""

    country: str
    """Country code"""

    distance: float
    """Distance in miles from the provided ZIP code"""

    fax_number: str
    """Fax number"""

    firstname: str
    """Provider first name"""

    lastname: str
    """Provider last name or organization name"""

    npi: str
    """National Provider Identifier (NPI) number"""

    postal_code: str
    """Postal/ZIP code"""

    state_province: str
    """State or province code"""

    work_phone: str
    """Work phone number"""


class ProviderLookupResponse(BaseModel):
    count: float
    """Number of providers found"""

    providers: List[Provider]
    """List of matching providers"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types import ProviderLookupResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProviders:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_lookup(self, client: BlueHive) -> None:
        provider = client.providers.lookup()
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_lookup_with_all_params(self, client: BlueHive) -> None:
        provider = client.providers.lookup(
            firstname="firstname",
            lastname="lastname",
            npi="npi",
            zipcode="zipcode",
        )
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_lookup(self, client: BlueHive) -> None:
        response = client.providers.with_raw_response.lookup()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        provider = response.parse()
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_lookup(self, client: BlueHive) -> None:
        with client.providers.with_streaming_response.lookup() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            provider = response.parse()
            assert_matches_type(ProviderLookupResponse, provider, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncProviders:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_lookup(self, async_client: AsyncBlueHive) -> None:
        provider = await async_client.providers.lookup()
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_lookup_with_all_params(self, async_client: AsyncBlueHive) -> None:
        provider = await async_client.providers.lookup(
            firstname="firstname",
            lastname="lastname",
            npi="npi",
            zipcode="zipcode",
        )
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_lookup(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.providers.with_raw_response.lookup()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        provider = await response.parse()
        assert_matches_type(ProviderLookupResponse, provider, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_lookup(self, async_client: AsyncBlueHive) -> None:
        async with async_client.providers.with_streaming_response.lookup() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            provider = await response.parse()
            assert_matches_type(ProviderLookupResponse, provider, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types import (
    OrderCreateResponse,
    OrderUpdateResponse,
    OrderRetrieveResponse,
    OrderUpdateStatusResponse,
    OrderUploadResultsResponse,
    OrderRetrieveResultsResponse,
    OrderSendForEmployeeResponse,
    OrderScheduleAppointmentResponse,
)
from bluehive._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestOrders:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_overload_1(self, client: BlueHive) -> None:
        order = client.orders.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: BlueHive) -> None:
        order = client.orders.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_id="employeeId",
            employee_ids=["string"],
            employer_id="employerId",
            metadata={"foo": "bar"},
            priority="normal",
            provider_created=True,
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services_ids=["string"],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create_overload_1(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create_overload_1(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_overload_2(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_ids=["string"],
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services_ids=["string"],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create_overload_2(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create_overload_2(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_overload_3(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params_overload_3(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            services_ids=["string"],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_ids=["string"],
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create_overload_3(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create_overload_3(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_overload_4(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params_overload_4(self, client: BlueHive) -> None:
        order = client.orders.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            services_ids=["string"],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_id="employeeId",
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create_overload_4(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create_overload_4(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: BlueHive) -> None:
        order = client.orders.retrieve(
            "orderId",
        )
        assert_matches_type(OrderRetrieveResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.retrieve(
            "orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderRetrieveResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.retrieve(
            "orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderRetrieveResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: BlueHive) -> None:
        order = client.orders.update(
            order_id="orderId",
        )
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.update(
            order_id="orderId",
            metadata={"foo": "bar"},
            services=[
                {
                    "service_id": "x",
                    "due_date": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "results": {"foo": "bar"},
                    "status": "pending",
                }
            ],
            status="order_sent",
        )
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.update(
            order_id="orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.update(
            order_id="orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderUpdateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.update(
                order_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_results(self, client: BlueHive) -> None:
        order = client.orders.retrieve_results(
            order_id="orderId",
        )
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_results_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.retrieve_results(
            order_id="orderId",
            page=1,
            page_size=1,
            service_id="serviceId",
            since=parse_datetime("2019-12-27T18:11:19.117Z"),
            status="status",
            until=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_results(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.retrieve_results(
            order_id="orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_results(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.retrieve_results(
            order_id="orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_results(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.retrieve_results(
                order_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_schedule_appointment(self, client: BlueHive) -> None:
        order = client.orders.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        )
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_schedule_appointment_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
                "notes": "notes",
                "type": "appointment",
            },
            order_access_code="orderAccessCode",
            provider_id="providerId",
        )
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_schedule_appointment(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_schedule_appointment(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_schedule_appointment(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.schedule_appointment(
                order_id="",
                appointment={
                    "date": "date",
                    "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "time": "time",
                },
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_for_employee(self, client: BlueHive) -> None:
        order = client.orders.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        )
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_for_employee_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "providerId",
                    "service_id": "serviceId",
                }
            ],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
            brand_id="brandId",
            due_date="dueDate",
            due_dates=["string"],
            metadata={"foo": "bar"},
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
        )
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send_for_employee(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send_for_employee(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_status(self, client: BlueHive) -> None:
        order = client.orders.update_status(
            order_id="orderId",
            status="order_sent",
        )
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_status_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.update_status(
            order_id="orderId",
            status="order_sent",
            message="message",
        )
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_status(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.update_status(
            order_id="orderId",
            status="order_sent",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_status(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.update_status(
            order_id="orderId",
            status="order_sent",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_status(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.update_status(
                order_id="",
                status="order_sent",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_upload_results(self, client: BlueHive) -> None:
        order = client.orders.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        )
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_upload_results_with_all_params(self, client: BlueHive) -> None:
        order = client.orders.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
            dob="7321-69-10",
            file_ids=["x"],
            files=[
                {
                    "base64": "x",
                    "name": "x",
                    "type": "x",
                }
            ],
            last_name="x",
        )
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_upload_results(self, client: BlueHive) -> None:
        response = client.orders.with_raw_response.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = response.parse()
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_upload_results(self, client: BlueHive) -> None:
        with client.orders.with_streaming_response.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = response.parse()
            assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_upload_results(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            client.orders.with_raw_response.upload_results(
                order_id="",
                captcha_token="x",
                order_access_code="x",
                service_id="x",
            )


class TestAsyncOrders:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_id="employeeId",
            employee_ids=["string"],
            employer_id="employerId",
            metadata={"foo": "bar"},
            priority="normal",
            provider_created=True,
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services_ids=["string"],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.create(
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
            },
            provider_id="providerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_ids=["string"],
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services_ids=["string"],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_overload_3(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params_overload_3(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            services_ids=["string"],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_ids=["string"],
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create_overload_3(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create_overload_3(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.create(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_overload_4(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params_overload_4(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "x",
                    "service_id": "x",
                }
            ],
            services_ids=["string"],
            _id="_id",
            brand_id="brandId",
            due_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            due_dates=[parse_datetime("2019-12-27T18:11:19.117Z")],
            employee_id="employeeId",
            metadata={"foo": "bar"},
            payment_method="self-pay",
            person={
                "city": "x",
                "dob": "7321-69-10",
                "email": "email",
                "first_name": "x",
                "last_name": "x",
                "phone": "+)() 92))()1)",
                "state": "xx",
                "street": "x",
                "zipcode": "73216-0225",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
            re_captcha_token="reCaptchaToken",
            services=[
                {
                    "_id": "x",
                    "quantity": 1,
                    "auto_accept": True,
                }
            ],
            token_id="tokenId",
        )
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create_overload_4(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderCreateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create_overload_4(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.create(
            employee_ids=["string"],
            employer_id="employerId",
            providers_ids=[{"provider_id": "x"}],
            services_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderCreateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.retrieve(
            "orderId",
        )
        assert_matches_type(OrderRetrieveResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.retrieve(
            "orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderRetrieveResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.retrieve(
            "orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderRetrieveResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.update(
            order_id="orderId",
        )
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.update(
            order_id="orderId",
            metadata={"foo": "bar"},
            services=[
                {
                    "service_id": "x",
                    "due_date": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "results": {"foo": "bar"},
                    "status": "pending",
                }
            ],
            status="order_sent",
        )
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.update(
            order_id="orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderUpdateResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.update(
            order_id="orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderUpdateResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.update(
                order_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_results(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.retrieve_results(
            order_id="orderId",
        )
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_results_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.retrieve_results(
            order_id="orderId",
            page=1,
            page_size=1,
            service_id="serviceId",
            since=parse_datetime("2019-12-27T18:11:19.117Z"),
            status="status",
            until=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_results(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.retrieve_results(
            order_id="orderId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_results(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.retrieve_results(
            order_id="orderId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderRetrieveResultsResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_results(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.retrieve_results(
                order_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_schedule_appointment(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        )
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_schedule_appointment_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
                "notes": "notes",
                "type": "appointment",
            },
            order_access_code="orderAccessCode",
            provider_id="providerId",
        )
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_schedule_appointment(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_schedule_appointment(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.schedule_appointment(
            order_id="orderId",
            appointment={
                "date": "date",
                "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                "time": "time",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderScheduleAppointmentResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_schedule_appointment(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.schedule_appointment(
                order_id="",
                appointment={
                    "date": "date",
                    "date_time": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "time": "time",
                },
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_for_employee(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        )
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_for_employee_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[
                {
                    "provider_id": "providerId",
                    "service_id": "serviceId",
                }
            ],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
            brand_id="brandId",
            due_date="dueDate",
            due_dates=["string"],
            metadata={"foo": "bar"},
            priority="normal",
            provider_created=True,
            provider_id="providerId",
            quantities={"foo": 1},
        )
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send_for_employee(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send_for_employee(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.send_for_employee(
            employee_id="employeeId",
            employer_id="employerId",
            providers_ids=[{"provider_id": "providerId"}],
            services_ids=["string"],
            login_token="login-token",
            user_id="user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderSendForEmployeeResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_status(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.update_status(
            order_id="orderId",
            status="order_sent",
        )
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_status_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.update_status(
            order_id="orderId",
            status="order_sent",
            message="message",
        )
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_status(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.update_status(
            order_id="orderId",
            status="order_sent",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_status(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.update_status(
            order_id="orderId",
            status="order_sent",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderUpdateStatusResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_status(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.update_status(
                order_id="",
                status="order_sent",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_upload_results(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        )
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_upload_results_with_all_params(self, async_client: AsyncBlueHive) -> None:
        order = await async_client.orders.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
            dob="7321-69-10",
            file_ids=["x"],
            files=[
                {
                    "base64": "x",
                    "name": "x",
                    "type": "x",
                }
            ],
            last_name="x",
        )
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_upload_results(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.orders.with_raw_response.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        order = await response.parse()
        assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_upload_results(self, async_client: AsyncBlueHive) -> None:
        async with async_client.orders.with_streaming_response.upload_results(
            order_id="orderId",
            captcha_token="x",
            order_access_code="x",
            service_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            order = await response.parse()
            assert_matches_type(OrderUploadResultsResponse, order, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_upload_results(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `order_id` but received ''"):
            await async_client.orders.with_raw_response.upload_results(
                order_id="",
                captcha_token="x",
                order_access_code="x",
                service_id="x",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["HealthCheckResponse"]


class HealthCheckResponse(BaseModel):
    status: Literal["ok"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["FaxSendParams", "Document"]


class FaxSendParams(TypedDict, total=False):
    document: Required[Document]

    to: Required[str]
    """Recipient fax number (E.164 format preferred)"""

    from_: Annotated[str, PropertyInfo(alias="from")]
    """Sender fax number (optional, uses default if not provided)"""

    provider: str
    """Optional provider override (uses default if not specified)"""

    subject: str
    """Subject line for the fax"""


class Document(TypedDict, total=False):
    content: Required[str]
    """Base64 encoded document content"""

    content_type: Required[
        Annotated[
            Literal["application/pdf", "image/tiff", "image/tif", "image/jpeg", "image/jpg", "image/png", "text/plain"],
            PropertyInfo(alias="contentType"),
        ]
    ]
    """MIME type of the document"""

    filename: str
    """Optional filename for the document"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import provider_lookup_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.provider_lookup_response import ProviderLookupResponse

__all__ = ["ProvidersResource", "AsyncProvidersResource"]


class ProvidersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ProvidersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return ProvidersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProvidersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return ProvidersResourceWithStreamingResponse(self)

    def lookup(
        self,
        *,
        firstname: str | Omit = omit,
        lastname: str | Omit = omit,
        npi: str | Omit = omit,
        zipcode: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProviderLookupResponse:
        """
        Search for healthcare providers by NPI number, name, or location proximity.

        Args:
          firstname: Provider first name

          lastname: Provider last name

          npi: Provider NPI number

          zipcode: ZIP code to filter results by proximity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/providers/lookup",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "firstname": firstname,
                        "lastname": lastname,
                        "npi": npi,
                        "zipcode": zipcode,
                    },
                    provider_lookup_params.ProviderLookupParams,
                ),
            ),
            cast_to=ProviderLookupResponse,
        )


class AsyncProvidersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncProvidersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncProvidersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProvidersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncProvidersResourceWithStreamingResponse(self)

    async def lookup(
        self,
        *,
        firstname: str | Omit = omit,
        lastname: str | Omit = omit,
        npi: str | Omit = omit,
        zipcode: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProviderLookupResponse:
        """
        Search for healthcare providers by NPI number, name, or location proximity.

        Args:
          firstname: Provider first name

          lastname: Provider last name

          npi: Provider NPI number

          zipcode: ZIP code to filter results by proximity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/providers/lookup",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "firstname": firstname,
                        "lastname": lastname,
                        "npi": npi,
                        "zipcode": zipcode,
                    },
                    provider_lookup_params.ProviderLookupParams,
                ),
            ),
            cast_to=ProviderLookupResponse,
        )


class ProvidersResourceWithRawResponse:
    def __init__(self, providers: ProvidersResource) -> None:
        self._providers = providers

        self.lookup = to_raw_response_wrapper(
            providers.lookup,
        )


class AsyncProvidersResourceWithRawResponse:
    def __init__(self, providers: AsyncProvidersResource) -> None:
        self._providers = providers

        self.lookup = async_to_raw_response_wrapper(
            providers.lookup,
        )


class ProvidersResourceWithStreamingResponse:
    def __init__(self, providers: ProvidersResource) -> None:
        self._providers = providers

        self.lookup = to_streamed_response_wrapper(
            providers.lookup,
        )


class AsyncProvidersResourceWithStreamingResponse:
    def __init__(self, providers: AsyncProvidersResource) -> None:
        self._providers = providers

        self.lookup = async_to_streamed_response_wrapper(
            providers.lookup,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .employers import (
    EmployersResource,
    AsyncEmployersResource,
    EmployersResourceWithRawResponse,
    AsyncEmployersResourceWithRawResponse,
    EmployersResourceWithStreamingResponse,
    AsyncEmployersResourceWithStreamingResponse,
)
from .service_bundles import (
    ServiceBundlesResource,
    AsyncServiceBundlesResource,
    ServiceBundlesResourceWithRawResponse,
    AsyncServiceBundlesResourceWithRawResponse,
    ServiceBundlesResourceWithStreamingResponse,
    AsyncServiceBundlesResourceWithStreamingResponse,
)

__all__ = [
    "ServiceBundlesResource",
    "AsyncServiceBundlesResource",
    "ServiceBundlesResourceWithRawResponse",
    "AsyncServiceBundlesResourceWithRawResponse",
    "ServiceBundlesResourceWithStreamingResponse",
    "AsyncServiceBundlesResourceWithStreamingResponse",
    "EmployersResource",
    "AsyncEmployersResource",
    "EmployersResourceWithRawResponse",
    "AsyncEmployersResourceWithRawResponse",
    "EmployersResourceWithStreamingResponse",
    "AsyncEmployersResourceWithStreamingResponse",
]
